@@ -43,12 +43,13 @@ const _BLANK_URI = "about:blank";
 
 const EditView = new Lang.Class({
     Name: 'EditView',
+    Extends: Gtk.Overlay,
 
     _init: function() {
         this._uri = null;
 
-        this.widget = new Gtk.Overlay();
-        this.widget.get_style_context().add_class('documents-scrolledwin');
+        this.parent();
+        this.get_style_context().add_class('documents-scrolledwin');
 
         let context = WebKit.WebContext.get_default();
 
@@ -62,11 +63,11 @@ const EditView = new Lang.Class({
         this._progressBar = new Gtk.ProgressBar({ halign: Gtk.Align.FILL,
                                                   valign: Gtk.Align.START });
         this._progressBar.get_style_context().add_class('osd');
-        this.widget.add_overlay(this._progressBar);
+        this.add_overlay(this._progressBar);
 
         this._createView();
 
-        this.widget.show_all();
+        this.show_all();
 
         this._editAction = Application.application.lookup_action('edit-current');
         this._editAction.enabled = false;
@@ -86,9 +87,6 @@ const EditView = new Lang.Class({
                 Application.modeController.goBack();
             }));
 
-        this._printAction = Application.application.lookup_action('print-current');
-        this._printAction.set_enabled(false);
-
         Application.documentManager.connect('load-started',
                                             Lang.bind(this, this._onLoadStarted));
         Application.documentManager.connect('load-finished',
@@ -99,7 +97,6 @@ const EditView = new Lang.Class({
     _onLoadStarted: function() {
         this._editAction.enabled = false;
         this._viewAction.enabled = false;
-        this._printAction.set_enabled(false);
     },
 
     _onLoadFinished: function(manager, doc, docModel) {
@@ -107,14 +104,12 @@ const EditView = new Lang.Class({
             if (doc.canEdit())
                 this._editAction.enabled = true;
             this._viewAction.enabled = true;
-            if (doc.canPrint(docModel))
-                this._printAction.set_enabled(true);
         }
     },
 
     _createView: function() {
         this.view = new WebKit.WebView();
-        this.widget.add(this.view);
+        this.add(this.view);
         this.view.show();
         this.view.connect('notify::estimated-load-progress', Lang.bind(this, this._onProgressChanged));
     },
@@ -163,7 +158,6 @@ const EditView = new Lang.Class({
         return this._uri;
     },
 });
-Signals.addSignalMethods(EditView.prototype);
 
 const EditToolbar = new Lang.Class({
     Name: 'EditToolbar',
@@ -189,7 +183,7 @@ const EditToolbar = new Lang.Class({
         this.toolbar.pack_end(viewButton);
 
         this._setToolbarTitle();
-        this.widget.show_all();
+        this.show_all();
     },
 
     createSearchbar: function() {
